@@ -127,6 +127,7 @@ fn downscale_u8() {
     let mut cpu_extensions_vec = vec![CpuExtensions::None];
     #[cfg(target_arch = "x86_64")]
     {
+        cpu_extensions_vec.push(CpuExtensions::Sse4_1);
         cpu_extensions_vec.push(CpuExtensions::Avx2);
     }
     for cpu_extensions in cpu_extensions_vec {
@@ -136,28 +137,6 @@ fn downscale_u8() {
     }
 }
 
-#[test]
-fn downscale_u8_1() {
-    let src_vec = vec![1u8; 1280 * 720];
-    let src_image = Image::from_vec_u8(
-        NonZeroU32::new(1280).unwrap(),
-        NonZeroU32::new(720).unwrap(),
-        src_vec,
-        PixelType::U8,
-    )
-    .unwrap();
-    let mut dst_iamge = Image::new(
-        NonZeroU32::new(64).unwrap(),
-        NonZeroU32::new(64).unwrap(),
-        PixelType::U8,
-    );
-    let mut resizer = Resizer::new(ResizeAlg::Convolution(FilterType::Lanczos3));
-    unsafe { resizer.set_cpu_extensions(CpuExtensions::Avx2) };
-    resizer
-        .resize(&src_image.view(), &mut dst_iamge.view_mut())
-        .unwrap();
-}
-
 #[test]
 fn upscale_u8() {
     type P = U8;
@@ -176,6 +155,50 @@ fn upscale_u8() {
     }
 }
 
+#[test]
+fn downscale_u8x2() {
+    type P = U8x2;
+    let buffer = downscale_test::<P>(ResizeAlg::Nearest, CpuExtensions::None);
+    assert_eq!(utils::image_checksum::<2>(&buffer), [2920348, 11054250]);
+
+    let mut cpu_extensions_vec = vec![CpuExtensions::None];
+    // #[cfg(target_arch = "x86_64")]
+    // {
+    //     cpu_extensions_vec.push(CpuExtensions::Sse4_1);
+    //     cpu_extensions_vec.push(CpuExtensions::Avx2);
+    // }
+    for cpu_extensions in cpu_extensions_vec {
+        let buffer =
+            downscale_test::<P>(ResizeAlg::Convolution(FilterType::Lanczos3), cpu_extensions);
+        assert_eq!(utils::image_checksum::<2>(&buffer), [2923557, 11054250]);
+    }
+}
+
+#[test]
+fn upscale_u8x2() {
+    type P = U8x2;
+    let buffer = upscale_test::<P>(ResizeAlg::Nearest, CpuExtensions::None);
+    assert_eq!(
+        utils::image_checksum::<2>(&buffer),
+        [1148754010, 4269569040]
+    );
+
+    let mut cpu_extensions_vec = vec![CpuExtensions::None];
+    // #[cfg(target_arch = "x86_64")]
+    // {
+    //     cpu_extensions_vec.push(CpuExtensions::Sse4_1);
+    //     cpu_extensions_vec.push(CpuExtensions::Avx2);
+    // }
+    for cpu_extensions in cpu_extensions_vec {
+        let buffer =
+            upscale_test::<P>(ResizeAlg::Convolution(FilterType::Lanczos3), cpu_extensions);
+        assert_eq!(
+            utils::image_checksum::<2>(&buffer),
+            [1148811406, 4269569040]
+        );
+    }
+}
+
 #[test]
 fn downscale_u8x3() {
     type P = U8x3;
@@ -226,56 +249,6 @@ fn upscale_u8x3() {
     }
 }
 
-#[test]
-fn downscale_u16x3() {
-    type P = U16x3;
-    let buffer = downscale_test::<P>(ResizeAlg::Nearest, CpuExtensions::None);
-    assert_eq!(
-        utils::image_u16_checksum::<3>(&buffer),
-        [755050580, 756962660, 740848503]
-    );
-
-    let mut cpu_extensions_vec = vec![CpuExtensions::None];
-    #[cfg(target_arch = "x86_64")]
-    {
-        cpu_extensions_vec.push(CpuExtensions::Sse4_1);
-        cpu_extensions_vec.push(CpuExtensions::Avx2);
-    }
-    for cpu_extensions in cpu_extensions_vec {
-        let buffer =
-            downscale_test::<P>(ResizeAlg::Convolution(FilterType::Lanczos3), cpu_extensions);
-        assert_eq!(
-            utils::image_u16_checksum::<3>(&buffer),
-            [756269847, 757632467, 741478612]
-        );
-    }
-}
-
-#[test]
-fn upscale_u16x3() {
-    type P = U16x3;
-    let buffer = upscale_test::<P>(ResizeAlg::Nearest, CpuExtensions::None);
-    assert_eq!(
-        utils::image_u16_checksum::<3>(&buffer),
-        [297094122820, 297713401842, 291717497780]
-    );
-
-    let mut cpu_extensions_vec = vec![CpuExtensions::None];
-    #[cfg(target_arch = "x86_64")]
-    {
-        cpu_extensions_vec.push(CpuExtensions::Sse4_1);
-        cpu_extensions_vec.push(CpuExtensions::Avx2);
-    }
-    for cpu_extensions in cpu_extensions_vec {
-        let buffer =
-            upscale_test::<P>(ResizeAlg::Convolution(FilterType::Lanczos3), cpu_extensions);
-        assert_eq!(
-            utils::image_u16_checksum::<3>(&buffer),
-            [297122154090, 297723994984, 291725294637]
-        );
-    }
-}
-
 #[test]
 fn downscale_u8x4() {
     type P = U8x4;
@@ -331,6 +304,56 @@ fn upscale_u8x4() {
     }
 }
 
+#[test]
+fn downscale_u16x3() {
+    type P = U16x3;
+    let buffer = downscale_test::<P>(ResizeAlg::Nearest, CpuExtensions::None);
+    assert_eq!(
+        utils::image_u16_checksum::<3>(&buffer),
+        [755050580, 756962660, 740848503]
+    );
+
+    let mut cpu_extensions_vec = vec![CpuExtensions::None];
+    #[cfg(target_arch = "x86_64")]
+    {
+        cpu_extensions_vec.push(CpuExtensions::Sse4_1);
+        cpu_extensions_vec.push(CpuExtensions::Avx2);
+    }
+    for cpu_extensions in cpu_extensions_vec {
+        let buffer =
+            downscale_test::<P>(ResizeAlg::Convolution(FilterType::Lanczos3), cpu_extensions);
+        assert_eq!(
+            utils::image_u16_checksum::<3>(&buffer),
+            [756269847, 757632467, 741478612]
+        );
+    }
+}
+
+#[test]
+fn upscale_u16x3() {
+    type P = U16x3;
+    let buffer = upscale_test::<P>(ResizeAlg::Nearest, CpuExtensions::None);
+    assert_eq!(
+        utils::image_u16_checksum::<3>(&buffer),
+        [297094122820, 297713401842, 291717497780]
+    );
+
+    let mut cpu_extensions_vec = vec![CpuExtensions::None];
+    #[cfg(target_arch = "x86_64")]
+    {
+        cpu_extensions_vec.push(CpuExtensions::Sse4_1);
+        cpu_extensions_vec.push(CpuExtensions::Avx2);
+    }
+    for cpu_extensions in cpu_extensions_vec {
+        let buffer =
+            upscale_test::<P>(ResizeAlg::Convolution(FilterType::Lanczos3), cpu_extensions);
+        assert_eq!(
+            utils::image_u16_checksum::<3>(&buffer),
+            [297122154090, 297723994984, 291725294637]
+        );
+    }
+}
+
 // #[test]
 fn _resize_i32() {
     type P = I32;
